//MODULE phycst
//   !!======================================================================
//   !!                    ***  MODULE  phycst  ***
//   !!     Definition of of both ocean and ice parameters used in the code
//   !!=====================================================================
double   rpi = 3.141592653589793;//             !: pi
double   rad = 3.141592653589793/180.;//_wp   !: conversion from degre into radian
//double   rsmall = 0.5 * EPSILON( 1. );//           !: smallest real computer value
double
rday = 24.*60.*60. ,//     & !: day (s)
  rsiyea           ,//     & !: sideral year (s)
  rsiday           ,//     & !: sideral day (s)
  raajj = 365.     ,//     & !: number of days in one year
  raamo =  12.     ,//     & !: number of months in one year
  rjjhh =  24.     ,//     & !: number of hours in one day
  rhhmm =  60.     ,//     & !: number of minutes in one hour
  rmmss =  60.     ,//     & !: number of seconds in one minute
  raass               ,//     & !: number of seconds in one year
  rmoss               ,//     & !: number of seconds in one month
  rjjss               ,//     & !: number of seconds in one day
  omega               ,//    &  !: earth rotation parameter
  ra    = 6371229. ,//    &  !: earth radius (meter)
  grav  = 9.80665; //          !: gravity (m/s2)

double
rtt      = 273.16  ,//  &  !: triple point of temperature (Kelvin)
  rt0      = 273.15  ,//  &  !: freezing point of water (Kelvin)
  rt0_snow = 273.15  ,//  &  !: melting point of snow  (Kelvin)
  rt0_ice  = 273.05  ,//  &  !: melting point of ice   (Kelvin)
  rau0     = 1020.   ,//  &  !: volumic mass of reference (kg/m3)
  rauw     = 1000.   ,//  &  !: volumic mass of pure water (kg/m3)
  rcp      =    4.e+3,//  &  !: ocean specific heat
  ro0cpr;             //         !: = 1. / ( rau0 * rcp )

double 
rcdsn   =   0.22     ,//   &  !: conductivity of the snow
  rcdic   =   2.034396 ,//   &  !: conductivity of the ice
  rcpsn   =   6.9069e+5,//   &  !: density times specific heat for snow
  rcpic   =   1.8837e+6,//   &  !: volumetric latent heat fusion of sea ice
  xlsn    = 110.121e+6 ,//   &  !: volumetric latent heat fusion of snow
  xlic    = 300.33e+6  ,//   &  !: volumetric latent heat fusion of ice
  xsn     =   2.8e+6   ,//   &  !: latent heat of sublimation of snow
  rhoic   = 900.       ,//   &  !: volumic mass of sea ice (kg/m3)
  rhosn   = 330.       ,//   &  !: volumic mass of snow (kg/m3)
  emic    =   0.97     ,//   &  !: emissivity of snow or ice
  sice    =   6.0      ,//   &  !: salinity of ice (psu)
  soce    =  34.7      ,//   &  !: salinity of sea (psu)
  cevap   =   2.5e+6   ,//   &  !: latent heat of evaporation (water)
  srgamma =   0.9      ,//   &  !: correction factor for solar radiation (Oberhuber, 1974)
  vkarmn  =   0.4      ,//   &  !: von Karman constant
  stefan  =   5.67e-8  ;//        !: Stefan-Boltzmann constant 

void phy_cst();
void phy_cst(){
  rsiyea = 365.25 * rday * 2. * rpi / 6.283076;
  rsiday = rday / ( 1. + rday / rsiyea );
  omega  = 2. * rpi / rsiday ;
  rjjss = rjjhh * rhhmm * rmmss;
  ro0cpr = 1. / ( rau0 * rcp );
  raajj = 30*raamo; // a revoir
  raass = raajj*rjjss;// a revoir
  rmoss = 30*rjjss;// a revoir
}
//   !!======================================================================
